@@ -73,7 +73,7 @@ from types import GeneratorType, ModuleType
 from collections import deque
 from binascii import a2b_hex, b2a_hex
 
-VERSION = '0.08'
+VERSION = '0.09'
 
 PYTHON3 = sys.version_info >= (3, 0)
 if PYTHON3:
@@ -1318,13 +1318,13 @@ def define_common(code, name='easycluster.remote_code'):
 
 def decode_key(key):
     '''If 'key' is a hex-encoded string of the proper size, returns the actual key,
-    otherwise just returns the original string.'''
+    otherwise returns a hash of the original string.'''
     try:
         if len(key) == 2*HMAC_SIZE:
             return _hexdec(key)
     except Exception:
-        traceback.print_exc()
-    return key.encode('utf-8')
+        pass
+    return HMAC_MOD(key.encode('utf-8')).digest()
 
 def read_key_file(path):
     '''Read an HMAC key from a file.'''
